@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -169,23 +169,39 @@ public class FormatData_fa extends ListResourceBundle {
                "H:mm:ss",
                "H:mm",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u062a\u0642\u0648\u06cc\u0645 \u0628\u0648\u062f\u0627\u06cc\u06cc",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "G EEEE d MMMM y",
-               "G d MMMM y",
-               "G d MMM y",
-               "G d/M/y",
+               "EEEE d MMMM y G",
+               "d MMMM y G",
+               "d MMM y G",
+               "y/M/d G",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "GGGG EEEE d MMMM y",
-               "GGGG d MMMM y",
-               "GGGG d MMM y",
-               "GGGG d/M/y",
+               "EEEE d MMMM y GGGG",
+               "d MMMM y GGGG",
+               "d MMM y GGGG",
+               "y/M/d GGGG",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u0645\u06cc\u0644\u0627\u062f\u06cc",
+               "",
+               "",
+               "",
+               "\u0647\u06cc\u0633\u0647\u200c\u0627\u06cc",
+               "\u0631\u06cc\u0648\u0627",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u0645.",
+               "",
+               "",
+               "",
+               "\u0647\u06cc\u0633\u0647\u200c\u0627\u06cc",
+               "\u0631\u06cc\u0648\u0627",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0642\u0628\u0644 \u0627\u0632 R.O.C.",
                "\u062a\u0642\u0648\u06cc\u0645 \u0645\u06cc\u0646\u06af\u0648",
             };
@@ -204,7 +220,11 @@ public class FormatData_fa extends ListResourceBundle {
                "\u0630\u06cc\u062d\u062c\u0647\u0654",
                "",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "\u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc",
+            };
+        final String[] metaValue_java_time_islamic_Eras = new String[] {
                "",
                "\u0647\u200d.\u0642.",
             };
@@ -229,7 +249,7 @@ public class FormatData_fa extends ListResourceBundle {
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "{0} \u06af\u0631\u06cc\u0646\u0648\u06cc\u0686" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -239,7 +259,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "calendarname.islamic-civil", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc \u062c\u062f\u0648\u0644\u06cc \u0645\u062f\u0646\u06cc" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "\u0642",
@@ -255,6 +275,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayNames },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0642\u0628\u0644 \u0627\u0632 \u0645\u06cc\u0644\u0627\u062f",
@@ -293,6 +314,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u062f\u0642\u06cc\u0642\u0647" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u062f\u0648\u0631\u0647" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0642\u0628\u0644/\u0628\u0639\u062f\u0627\u0632\u0638\u0647\u0631" },
@@ -315,18 +337,12 @@ public class FormatData_fa extends ListResourceBundle {
                 }
             },
             { "calendarname.roc", "\u062a\u0642\u0648\u06cc\u0645 \u062c\u0645\u0647\u0648\u0631\u06cc \u0686\u06cc\u0646 (\u062a\u0627\u06cc\u0648\u0627\u0646)" },
-            { "islamic.DatePatterns",
-                new String[] {
-                    "EEEE d MMMM y GGGG",
-                    "d MMMM y GGGG",
-                    "d MMM y GGGG",
-                    "y/M/d GGGG",
-                }
-            },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "\u0645\u0627\u0647" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u062b\u0627\u0646\u06cc\u0647" },
             { "DayAbbreviations", metaValue_DayNames },
             { "DayNarrows", metaValue_DayNarrows },
@@ -339,10 +355,31 @@ public class FormatData_fa extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_standalone_MonthNames },
             { "timezone.regionFormat", "\u0648\u0642\u062a {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0647\u0632\u0627\u0631",
+                    "00 \u0647\u0632\u0627\u0631",
+                    "000 \u0647\u0632\u0627\u0631",
+                    "0 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "00 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "000 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "0 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "00 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "000 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "0 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "00 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "000 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -350,13 +387,15 @@ public class FormatData_fa extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayNames },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0645\u0646\u0637\u0642\u0647\u0654 \u0632\u0645\u0627\u0646\u06cc" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "Eras",
@@ -370,32 +409,23 @@ public class FormatData_fa extends ListResourceBundle {
             { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
-            { "java.time.islamic.DatePatterns",
-                new String[] {
-                    "EEEE d MMMM y G",
-                    "d MMMM y G",
-                    "d MMM y G",
-                    "y/M/d G",
-                }
-            },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0631\u0648\u0632 \u0647\u0641\u062a\u0647" },
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayNames },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "\u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.hourFormat", "\u200e+HH:mm;\u200e\u2212HH:mm" },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayNames },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u0647\u0641\u062a\u0647" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -404,7 +434,27 @@ public class FormatData_fa extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0647\u0632\u0627\u0631",
+                    "00\u00a0\u0647\u0632\u0627\u0631",
+                    "000\u00a0\u0647\u0632\u0627\u0631",
+                    "0\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "00\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "000\u00a0\u0645",
+                    "0\u00a0\u0645",
+                    "00\u00a0\u0645",
+                    "000\u00a0\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "0\u00a0\u062a\u0631\u06cc\u0644\u06cc\u0648\u0646",
+                    "00\u00a0\u062a",
+                    "000\u00a0\u062a",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "\u0648\u0642\u062a \u062a\u0627\u0628\u0633\u062a\u0627\u0646\u06cc {0}" },
             { "DatePatterns",
                 new String[] {
@@ -420,14 +470,16 @@ public class FormatData_fa extends ListResourceBundle {
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0633\u0627\u0639\u062a" },
             { "islamic.MonthAbbreviations", metaValue_islamic_MonthNames },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u062a\u0642\u0648\u06cc\u0645 \u0628\u0648\u062f\u0627\u06cc\u06cc" },
             { "standalone.MonthNames", metaValue_standalone_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
