@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,8 +154,12 @@ public class FormatData_ha extends ListResourceBundle {
                "K3",
                "K4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "Safiya",
+               "Yamma",
+            };
         final String[] metaValue_Eras = new String[] {
-               "KHAI",
+               "K.H",
                "BHAI",
             };
         final String[] metaValue_TimePatterns = new String[] {
@@ -186,24 +190,28 @@ public class FormatData_ha extends ListResourceBundle {
                "AM",
                "PM",
             };
+        final String metaValue_calendarname_gregorian = "Gregorian Kalanda";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "Shekara" },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "Agogo" },
+            { "field.zone", "Lokacin yanki" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
+            { "timezone.regionFormat.standard", "{0} Daidai ta ce lokaci" },
             { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "roc.DayNames", metaValue_DayNames },
@@ -219,8 +227,16 @@ public class FormatData_ha extends ListResourceBundle {
             { "islamic.DayNames", metaValue_DayNames },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "field.weekday", "Rana" },
+            { "field.weekday", "Rana mako" },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -243,7 +259,8 @@ public class FormatData_ha extends ListResourceBundle {
             { "field.minute", "Minti" },
             { "field.era", "Zamani" },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "field.dayperiod", "Yini" },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "field.dayperiod", "Lokuttan rana" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -271,7 +288,7 @@ public class FormatData_ha extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -293,9 +310,11 @@ public class FormatData_ha extends ListResourceBundle {
                     "000T",
                 }
             },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "timezone.regionFormat.daylight", "{0} Lokaci rana" },
             { "DatePatterns",
                 new String[] {
-                    "EEEE, d MMMM, y",
+                    "EEEE d MMMM, y",
                     "d MMMM, y",
                     "d MMM, y",
                     "d/M/yy",
@@ -310,6 +329,7 @@ public class FormatData_ha extends ListResourceBundle {
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "timezone.regionFormat", "{0} Lokaci" },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
@@ -331,12 +351,14 @@ public class FormatData_ha extends ListResourceBundle {
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
     }
