@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -125,13 +125,13 @@ public class FormatData_kk extends ListResourceBundle {
                "\u0441\u0435\u043d\u0431\u0456",
             };
         final String[] metaValue_DayAbbreviations = new String[] {
-               "\u0416\u0441",
-               "\u0414\u0441",
-               "\u0421\u0441",
-               "\u0421\u0440",
-               "\u0411\u0441",
-               "\u0416\u043c",
-               "\u0421\u0431",
+               "\u0436\u0441",
+               "\u0434\u0441",
+               "\u0441\u0441",
+               "\u0441\u0440",
+               "\u0431\u0441",
+               "\u0436\u043c",
+               "\u0441\u0431",
             };
         final String[] metaValue_DayNarrows = new String[] {
                "\u0416",
@@ -261,23 +261,7 @@ public class FormatData_kk extends ListResourceBundle {
             { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
             { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "standalone.MonthAbbreviations",
-                new String[] {
-                    "\u049a\u0430\u04a3.",
-                    "\u0410\u049b\u043f.",
-                    "\u041d\u0430\u0443.",
-                    "\u0421\u04d9\u0443.",
-                    "\u041c\u0430\u043c.",
-                    "\u041c\u0430\u0443.",
-                    "\u0428\u0456\u043b.",
-                    "\u0422\u0430\u043c.",
-                    "\u049a\u044b\u0440.",
-                    "\u049a\u0430\u0437.",
-                    "\u049a\u0430\u0440.",
-                    "\u0416\u0435\u043b.",
-                    "",
-                }
-            },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u0443\u0430\u049b\u044b\u0442\u044b" },
             { "long.CompactNumberPatterns",
                 new String[] {
@@ -366,17 +350,7 @@ public class FormatData_kk extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames",
-                new String[] {
-                    "\u0416\u0435\u043a\u0441\u0435\u043d\u0431\u0456",
-                    "\u0414\u04af\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0421\u0435\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0421\u04d9\u0440\u0441\u0435\u043d\u0431\u0456",
-                    "\u0411\u0435\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0416\u04b1\u043c\u0430",
-                    "\u0421\u0435\u043d\u0431\u0456",
-                }
-            },
+            { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0441\u0430\u0493\u0430\u0442" },
             { "calendarname.buddhist", "\u0411\u0443\u0434\u0434\u0430 \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
             { "standalone.MonthNames",
