@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -151,13 +151,13 @@ public class FormatData_my extends ListResourceBundle {
             };
         final String[] metaValue_Eras = new String[] {
                "\u1018\u102e\u1005\u102e",
-               "\u1021\u1031\u1012\u102e",
+               "\u1021\u1012\u1031\u102e",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "zzzz HH:mm:ss",
                "z HH:mm:ss",
-               "HH:mm:ss",
-               "H:mm",
+               "a HH:mm:ss",
+               "a H:mm",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE G dd MMMM y",
