@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -158,22 +158,12 @@ public class FormatData_nl extends ListResourceBundle {
                "a.m.",
                "p.m.",
             };
-        final String[] metaValue_TimePatterns = new String[] {
-               "HH:mm:ss zzzz",
-               "HH:mm:ss z",
-               "HH:mm:ss",
-               "HH:mm",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
-               "BC",
-               "BE",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -186,13 +176,19 @@ public class FormatData_nl extends ListResourceBundle {
                "d MMM y GGGG",
                "dd-MM-yy G",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_buddhist_DateTimePatterns = new String[] {
+               "{1} 'om' {0}",
+               "{1} 'om' {0}",
+               "",
+               "",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "voor R.O.C.",
                "Minguo",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
-               "AH",
+               "Sa\u02bbna Hizjria",
             };
         final String metaValue_calendarname_gregorian = "Gregoriaanse kalender";
         final String[] metaValue_brah_NumberElements = new String[] {
@@ -211,24 +207,9 @@ public class FormatData_nl extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "jaar" },
+            { "rohg.NumberElements", metaValue_brah_NumberElements },
             { "calendarname.islamic-umalqura", "Islamitische kalender (Umm al-Qura)" },
-            { "arabext.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a",
-                    "\u06f0",
-                    "#",
-                    "\u200e-\u200e",
-                    "\u00d7\u06f1\u06f0^",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -266,8 +247,7 @@ public class FormatData_nl extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "v.C.",
@@ -374,6 +354,7 @@ public class FormatData_nl extends ListResourceBundle {
                 }
             },
             { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "gong.NumberElements", metaValue_brah_NumberElements },
             { "latn.NumberElements", metaValue_brah_NumberElements },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -395,16 +376,6 @@ public class FormatData_nl extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minuut" },
             { "field.era", "tijdperk" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "na Christus",
-                    "Meiji",
-                    "Taish\u014d",
-                    "Sh\u014dwa",
-                    "Heisei",
-                    "",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "a.m./p.m." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
@@ -440,21 +411,6 @@ public class FormatData_nl extends ListResourceBundle {
                     "",
                 }
             },
-            { "arab.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a\u061c",
-                    "\u0660",
-                    "#",
-                    "\u061c-",
-                    "\u0627\u0633",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "shrd.NumberElements", metaValue_brah_NumberElements },
             { "takr.NumberElements", metaValue_brah_NumberElements },
             { "calendarname.roc", "Kalender van de Chinese Republiek" },
@@ -475,10 +431,9 @@ public class FormatData_nl extends ListResourceBundle {
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
             { "field.month", "maand" },
             { "osma.NumberElements", metaValue_brah_NumberElements },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "seconde" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -491,6 +446,8 @@ public class FormatData_nl extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamitische kalender" },
+            { "gonm.NumberElements", metaValue_brah_NumberElements },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "knda.NumberElements",
                 new String[] {
                     ",",
@@ -521,11 +478,30 @@ public class FormatData_nl extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0}-tijd" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 duizend",
+                    "00 duizend",
+                    "000 duizend",
+                    "0 miljoen",
+                    "00 miljoen",
+                    "000 miljoen",
+                    "0 miljard",
+                    "00 miljard",
+                    "000 miljard",
+                    "0 biljoen",
+                    "00 biljoen",
+                    "000 biljoen",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -564,7 +540,6 @@ public class FormatData_nl extends ListResourceBundle {
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
             { "mlym.NumberElements",
                 new String[] {
                     ",",
@@ -595,7 +570,6 @@ public class FormatData_nl extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "TimePatterns", metaValue_TimePatterns },
             { "lepc.NumberElements",
                 new String[] {
                     ",",
@@ -627,6 +601,7 @@ public class FormatData_nl extends ListResourceBundle {
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "khmr.NumberElements",
                 new String[] {
                     ",",
@@ -644,7 +619,8 @@ public class FormatData_nl extends ListResourceBundle {
             },
             { "field.zone", "tijdzone" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "laoo.NumberElements",
                 new String[] {
                     ",",
@@ -733,14 +709,10 @@ public class FormatData_nl extends ListResourceBundle {
             },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "dag van de week" },
+            { "islamic.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "Sa\u02bbna Hizjria",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "telu.NumberElements",
@@ -810,8 +782,8 @@ public class FormatData_nl extends ListResourceBundle {
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
             { "sora.NumberElements", metaValue_brah_NumberElements },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
             { "field.week", "week" },
+            { "buddhist.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
             { "gujr.NumberElements",
                 new String[] {
                     ",",
@@ -864,6 +836,25 @@ public class FormatData_nl extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0K",
+                    "00K",
+                    "000K",
+                    "0\u00a0mln'.'",
+                    "00\u00a0mln'.'",
+                    "000\u00a0mln'.'",
+                    "0\u00a0mld'.'",
+                    "00\u00a0mld'.'",
+                    "000\u00a0mld'.'",
+                    "0\u00a0bln'.'",
+                    "00\u00a0bln'.'",
+                    "000\u00a0bln'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "zomertijd {0}" },
             { "DatePatterns",
@@ -871,19 +862,10 @@ public class FormatData_nl extends ListResourceBundle {
                     "EEEE d MMMM y",
                     "d MMMM y",
                     "d MMM y",
-                    "dd-MM-yy",
+                    "dd-MM-y",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "japanese.DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "uur" },
@@ -919,24 +901,13 @@ public class FormatData_nl extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
             { "calendarname.buddhist", "Boeddhistische kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
-            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "n.Chr.",
-                    "Meiji",
-                    "Taish\u014d",
-                    "Sh\u014dwa",
-                    "Heisei",
-                    "",
-                }
-            },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
