@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -266,8 +266,8 @@ public class FormatData_or extends ListResourceBundle {
             { "NumberPatterns",
                 new String[] {
                     "#,##,##0.###",
-                    "\u00a4#,##,##0.00",
-                    "#,##,##0%",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
                 }
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
