@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -85,6 +85,21 @@ public class FormatData_sd extends ListResourceBundle {
                "\u068a\u0633\u0645\u0628\u0631",
                "",
             };
+        final String[] metaValue_MonthNarrows = new String[] {
+               "J",
+               "F",
+               "M",
+               "A",
+               "M",
+               "J",
+               "J",
+               "A",
+               "S",
+               "O",
+               "N",
+               "D",
+               "",
+            };
         final String[] metaValue_DayNames = new String[] {
                "\u0622\u0686\u0631",
                "\u0633\u0648\u0645\u0631",
@@ -109,6 +124,12 @@ public class FormatData_sd extends ListResourceBundle {
                "\u067d\u064a\u0646 \u067d\u064a \u0645\u0627\u0647\u064a",
                "\u0686\u0648\u067f\u064a\u0646 \u067d\u064a \u0645\u0627\u0647\u064a",
             };
+        final String[] metaValue_QuarterAbbreviations = new String[] {
+               "Q1",
+               "Q2",
+               "Q3",
+               "Q5",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u0635\u0628\u062d\u060c \u0645\u0646\u062c\u0647\u0646\u062f",
                "\u0645\u0646\u062c\u0647\u0646\u062f\u060c \u0634\u0627\u0645",
@@ -117,27 +138,16 @@ public class FormatData_sd extends ListResourceBundle {
                "\u0635\u0628\u062d\u060c \u0645\u0646\u062c\u0647\u0646\u062f",
                "\u0634\u0627\u0645\u060c \u0645\u0646\u062c\u0647\u0646\u062f",
             };
+        final String[] metaValue_Eras = new String[] {
+               "BC",
+               "CD",
+            };
         final String[] metaValue_TimePatterns = new String[] {
                "h:mm:ss a zzzz",
                "h:mm:ss a z",
                "h:mm:ss a",
                "h:mm a",
             };
-        final String[] metaValue_buddhist_MonthNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-               "5",
-               "6",
-               "7",
-               "8",
-               "9",
-               "10",
-               "11",
-               "12",
-               "",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -163,12 +173,21 @@ public class FormatData_sd extends ListResourceBundle {
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
+            { "standalone.QuarterAbbreviations",
+                new String[] {
+                    "Q1",
+                    "Q2",
+                    "Q3",
+                    "Q4",
+                }
+            },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "narrow.Eras", metaValue_Eras },
             { "abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "timezone.regionFormat.standard", "{0} \u0645\u0639\u064a\u0627\u0631\u064a \u0648\u0642\u062a" },
             { "DefaultNumberingSystem", "arab" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "calendarname.japanese", "\u062c\u0627\u067e\u0627\u0646\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
@@ -208,15 +227,17 @@ public class FormatData_sd extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0645\u0646\u067d" },
             { "field.era", "\u062f\u0648\u0631" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "\u0635\u0628\u062d\u060c \u0645\u0646\u062c\u0647\u0646\u062f/\u0645\u0646\u062c\u0647\u0646\u062f\u060c \u0634\u0627\u0645" },
+            { "field.dayperiod", "\u0635\u0628\u062d/\u0634\u0627\u0645" },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.roc", "\u0645\u0646\u06af\u0648\u0648 \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterNames },
+            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "\u0645\u0647\u064a\u0646\u0648" },
             { "field.second", "\u0633\u064a\u06aa\u0646\u068a" },
             { "DayAbbreviations", metaValue_DayNames },
@@ -256,27 +277,18 @@ public class FormatData_sd extends ListResourceBundle {
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayNames },
-            { "standalone.DayNarrows",
-                new String[] {
-                    "\u0622\u0686",
-                    "\u0633\u0648",
-                    "\u0627\u06b1",
-                    "\u0627\u0631",
-                    "\u062e\u0645",
-                    "\u062c\u0645",
-                    "\u0687\u0646",
-                }
-            },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u067d\u0627\u0626\u064a\u0645 \u0632\u0648\u0646" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
@@ -285,15 +297,15 @@ public class FormatData_sd extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayNames },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayNames },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "\u0647\u0641\u062a\u0648" },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
@@ -319,6 +331,7 @@ public class FormatData_sd extends ListResourceBundle {
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "timezone.regionFormat.daylight", "{0} \u068f\u064a\u0646\u0647\u0646 \u062c\u0648 \u0648\u0642\u062a" },
             { "DatePatterns",
                 new String[] {
                     "y MMMM d, EEEE",
@@ -338,7 +351,7 @@ public class FormatData_sd extends ListResourceBundle {
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterNames },
+            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
