@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -72,7 +72,6 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AED", "AED" },
-            { "AFN", "AFN" },
             { "ALL", "ALL" },
             { "AMD", "AMD" },
             { "ANG", "ANG" },
@@ -82,38 +81,29 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "AWG", "AWG" },
             { "AZN", "AZN" },
             { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
             { "BEF", "FB" },
             { "BGN", "BGN" },
-            { "BHD", "BHD" },
             { "BIF", "BIF" },
             { "BMD", "$BM" },
             { "BND", "$BN" },
             { "BOB", "BOB" },
-            { "BSD", "$BS" },
+            { "BSD", "BSD" },
             { "BTN", "BTN" },
             { "BWP", "BWP" },
             { "BYN", "BYN" },
-            { "BYR", "BYR" },
             { "BZD", "$BZ" },
             { "CAD", "$CA" },
             { "CDF", "CDF" },
-            { "CHF", "CHF" },
             { "CLP", "$CL" },
+            { "CNH", "CNH" },
             { "CNY", "CNY" },
             { "COP", "$CO" },
             { "CRC", "CRC" },
             { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
             { "CYP", "\u00a3CY" },
             { "CZK", "CZK" },
             { "DJF", "DJF" },
-            { "DKK", "DKK" },
             { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
             { "ERN", "ERN" },
             { "ETB", "ETB" },
             { "FJD", "$FJ" },
@@ -121,10 +111,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "FRF", "F" },
             { "GBP", "\u00a3GB" },
             { "GEL", "GEL" },
-            { "GHS", "GHS" },
             { "GIP", "\u00a3GI" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
             { "GTQ", "GTQ" },
             { "GYD", "GYD" },
             { "HKD", "HKD" },
@@ -132,12 +119,10 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "HRK", "HRK" },
             { "HTG", "HTG" },
             { "HUF", "HUF" },
-            { "IDR", "IDR" },
             { "IEP", "\u00a3IE" },
             { "ILP", "\u00a3IL" },
             { "IQD", "IQD" },
             { "IRR", "IRR" },
-            { "ISK", "ISK" },
             { "ITL", "\u20a4IT" },
             { "JMD", "JMD" },
             { "JOD", "JOD" },
@@ -146,44 +131,26 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "KGS", "KGS" },
             { "KHR", "KHR" },
             { "KMF", "KMF" },
-            { "KPW", "KPW" },
             { "KWD", "KWD" },
             { "KYD", "KYD" },
             { "KZT", "KZT" },
             { "LAK", "LAK" },
             { "LBP", "\u00a3LB" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LTL", "LTL" },
-            { "LVL", "LVL" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
             { "MDL", "MDL" },
             { "MGA", "MGA" },
             { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MTP", "\u00a3MT" },
             { "MUR", "MUR" },
-            { "MVR", "MVR" },
             { "MWK", "MWK" },
             { "MXN", "$MX" },
-            { "MYR", "MYR" },
             { "MZN", "MZN" },
             { "NAD", "$NA" },
-            { "NGN", "NGN" },
             { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
             { "NZD", "$NZ" },
             { "OMR", "OMR" },
             { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
             { "PLN", "PLN" },
             { "PYG", "PYG" },
             { "QAR", "QAR" },
@@ -195,21 +162,13 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "SAR", "SAR" },
             { "SBD", "$SB" },
             { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
             { "SGD", "$SG" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
             { "SOS", "SOS" },
             { "SRD", "$SR" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
             { "TMT", "TMT" },
-            { "TND", "TND" },
             { "TOP", "TOP" },
             { "TRY", "TRY" },
             { "TTD", "$TT" },
@@ -221,6 +180,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "UYU", "$UY" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WS$" },
             { "XCD", "XCD" },
@@ -472,7 +432,8 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "uyu", "peso uruguayen" },
             { "uzs", "sum ouzbek" },
             { "veb", "bolivar v\u00e9n\u00e9zu\u00e9lien (1871\u20132008)" },
-            { "vef", "bolivar v\u00e9n\u00e9zu\u00e9lien" },
+            { "vef", "bolivar v\u00e9n\u00e9zu\u00e9lien (2008\u20132018)" },
+            { "ves", "bolivar v\u00e9n\u00e9zu\u00e9lien" },
             { "vnd", "d\u00f4ng vietnamien" },
             { "vuv", "vatu vanuatuan" },
             { "wst", "tala samoan" },
