@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,146 +71,10 @@ public class CurrencyNames_ml extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
             { "CNH", "CNH" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LTL", "LTL" },
-            { "LVL", "LVL" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
-            { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
             { "USD", "$" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "adp", "\u0d05\u0d7b\u0d21\u0d4b\u0d31\u0d7b \u0d2a\u0d46\u0d38\u0d46\u0d2f\u0d4d\u0d31\u0d4d\u0d31" },
             { "aed", "\u0d2f\u0d41\u0d23\u0d48\u0d31\u0d4d\u0d31\u0d21\u0d4d \u0d05\u0d31\u0d2c\u0d4d \u0d0e\u0d2e\u0d3f\u0d31\u0d47\u0d31\u0d4d\u0d31\u0d4d\u0d38\u0d4d \u0d26\u0d3f\u0d7c\u0d39\u0d02" },
             { "afa", "\u0d05\u0d2b\u0d4d\u0d18\u0d3e\u0d28\u0d3f (1927\u20132002)" },
@@ -453,7 +317,8 @@ public class CurrencyNames_ml extends OpenListResourceBundle {
             { "uyu", "\u0d09\u0d31\u0d41\u0d17\u0d4d\u0d35\u0d47\u0d2f\u0d7b \u0d2a\u0d46\u0d38\u0d4b" },
             { "uzs", "\u0d09\u0d38\u0d4d\u200c\u0d2c\u0d46\u0d15\u0d4d\u0d15\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d3f \u0d38\u0d4b\u0d02" },
             { "veb", "\u0d35\u0d46\u0d28\u0d38\u0d4d\u0d35\u0d47\u0d32\u0d7b \u0d2c\u0d4b\u0d32\u0d3f\u0d35\u0d7c (1871\u20132008)" },
-            { "vef", "\u0d35\u0d46\u0d28\u0d3f\u0d38\u0d4d\u0d35\u0d47\u0d32\u0d7b \u0d2c\u0d4a\u0d33\u0d40\u0d35\u0d7c" },
+            { "vef", "\u0d35\u0d46\u0d28\u0d3f\u0d38\u0d4d\u0d35\u0d47\u0d32\u0d7b \u0d2c\u0d4a\u0d33\u0d40\u0d35\u0d7c (2008\u20132018)" },
+            { "ves", "\u0d35\u0d46\u0d28\u0d3f\u0d38\u0d4d\u0d35\u0d47\u0d32\u0d7b \u0d2c\u0d4a\u0d33\u0d40\u0d35\u0d7c" },
             { "vnd", "\u0d35\u0d3f\u0d2f\u0d31\u0d4d\u0d31\u0d4d\u0d28\u0d3e\u0d2e\u0d40\u0d38\u0d4d \u0d21\u0d4b\u0d19\u0d4d" },
             { "vuv", "\u0d35\u0d28\u0d4d\u0d35\u0d3e\u0d24\u0d41 \u0d35\u0d3e\u0d24\u0d41" },
             { "wst", "\u0d38\u0d2e\u0d4b\u0d35\u0d7b \u0d24\u0d3e\u0d32" },
