@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,6 +86,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "Zsye", "\u7d75\u6587\u5b57" },
             { "%%NJIVA", "\u30cb\u30f4\u30a1\u65b9\u8a00" },
             { "xmf", "\u30e1\u30b0\u30ec\u30eb\u8a9e" },
+            { "ccp", "\u30c1\u30e3\u30af\u30de\u8a9e" },
             { "egy", "\u53e4\u4ee3\u30a8\u30b8\u30d7\u30c8\u8a9e" },
             { "raj", "\u30e9\u30fc\u30b8\u30e3\u30b9\u30bf\u30fc\u30f3\u8a9e" },
             { "Phag", "\u30d1\u30b9\u30d1\u6587\u5b57" },
@@ -369,7 +370,6 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "phn", "\u30d5\u30a7\u30cb\u30ad\u30a2\u8a9e" },
             { "Cyrs", "\u53e4\u4ee3\u6559\u4f1a\u30b9\u30e9\u30d6\u8a9e\u30ad\u30ea\u30eb\u6587\u5b57" },
             { "gwi", "\u30b0\u30a6\u30a3\u30c3\u30c1\u30f3\u8a9e" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "\u4f4e\u5730\u30c9\u30a4\u30c4\u8a9e" },
             { "LI", "\u30ea\u30d2\u30c6\u30f3\u30b7\u30e5\u30bf\u30a4\u30f3" },
             { "LK", "\u30b9\u30ea\u30e9\u30f3\u30ab" },
@@ -405,7 +405,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "ale", "\u30a2\u30ec\u30a6\u30c8\u8a9e" },
             { "Thai", "\u30bf\u30a4\u6587\u5b57" },
             { "type.nu.vaii", "\u30f4\u30a1\u30a4\u6587\u5b57\u306e\u8a18\u6570\u6cd5" },
-            { "MK", "\u30de\u30b1\u30c9\u30cb\u30a2" },
+            { "MK", "\u5317\u30de\u30b1\u30c9\u30cb\u30a2" },
             { "ML", "\u30de\u30ea" },
             { "MM", "\u30df\u30e3\u30f3\u30de\u30fc (\u30d3\u30eb\u30de)" },
             { "MN", "\u30e2\u30f3\u30b4\u30eb" },
@@ -459,7 +459,6 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "crh", "\u30af\u30ea\u30df\u30a2\u30fb\u30bf\u30bf\u30fc\u30eb\u8a9e" },
             { "ang", "\u53e4\u82f1\u8a9e" },
             { "OM", "\u30aa\u30de\u30fc\u30f3" },
-            { "%%PETR1708", "PETR1708" },
             { "anp", "\u30a2\u30f3\u30ae\u30ab\u8a9e" },
             { "crs", "\u30bb\u30fc\u30b7\u30a7\u30eb\u30fb\u30af\u30ec\u30aa\u30fc\u30eb\u8a9e" },
             { "Xpeo", "\u53e4\u4ee3\u30da\u30eb\u30b7\u30a2\u6587\u5b57" },
@@ -563,7 +562,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "SX", "\u30b7\u30f3\u30c8\u30fb\u30de\u30fc\u30eb\u30c6\u30f3" },
             { "SY", "\u30b7\u30ea\u30a2" },
             { "yao", "\u30e4\u30aa\u8a9e" },
-            { "SZ", "\u30b9\u30ef\u30b8\u30e9\u30f3\u30c9" },
+            { "SZ", "\u30a8\u30b9\u30ef\u30c6\u30a3\u30cb" },
             { "arw", "\u30a2\u30e9\u30ef\u30af\u8a9e" },
             { "arz", "\u30a8\u30b8\u30d7\u30c8\u30fb\u30a2\u30e9\u30d3\u30a2\u8a9e" },
             { "ary", "\u30e2\u30ed\u30c3\u30b3\u30fb\u30a2\u30e9\u30d3\u30a2\u8a9e" },
@@ -712,7 +711,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "dak", "\u30c0\u30b3\u30bf\u8a9e" },
             { "type.nu.fullwide", "\u5168\u89d2\u6570\u5b57" },
             { "hit", "\u30d2\u30c3\u30bf\u30a4\u30c8\u8a9e" },
-            { "dar", "\u30c0\u30eb\u30ac\u30f3\u8a9e" },
+            { "dar", "\u30c0\u30eb\u30b0\u30ef\u8a9e" },
             { "dav", "\u30bf\u30a4\u30bf\u8a9e" },
             { "Maya", "\u30de\u30e4\u8c61\u5f62\u6587\u5b57" },
             { "lrc", "\u5317\u30ed\u30eb\u8a9e" },
@@ -923,7 +922,6 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "ig", "\u30a4\u30dc\u8a9e" },
             { "ii", "\u56db\u5ddd\u30a4\u8a9e" },
             { "frm", "\u4e2d\u671f\u30d5\u30e9\u30f3\u30b9\u8a9e" },
-            { "%%RUMGR", "RUMGR" },
             { "ik", "\u30a4\u30cc\u30d4\u30a2\u30c3\u30af\u8a9e" },
             { "fro", "\u53e4\u30d5\u30e9\u30f3\u30b9\u8a9e" },
             { "frp", "\u30a2\u30eb\u30d4\u30bf\u30f3\u8a9e" },
@@ -933,7 +931,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "frr", "\u5317\u30d5\u30ea\u30b8\u30a2\u8a9e" },
             { "is", "\u30a2\u30a4\u30b9\u30e9\u30f3\u30c9\u8a9e" },
             { "it", "\u30a4\u30bf\u30ea\u30a2\u8a9e" },
-            { "iu", "\u30a4\u30cc\u30af\u30a6\u30c6\u30a3\u30c8\u30c3\u30c8\u8a9e" },
+            { "iu", "\u30a4\u30cc\u30af\u30c6\u30a3\u30c8\u30c3\u30c8\u8a9e" },
             { "sli", "\u4f4e\u30b7\u30ec\u30b8\u30a2\u8a9e" },
             { "%%HOGNORSK", "\u30d8\u30b0\u30ce\u30b7\u30e5\u30af" },
             { "ja", "\u65e5\u672c\u8a9e" },
@@ -1042,7 +1040,7 @@ public class LocaleNames_ja extends OpenListResourceBundle {
             { "om", "\u30aa\u30ed\u30e2\u8a9e" },
             { "kaw", "\u30ab\u30a6\u30a3\u8a9e" },
             { "dtp", "\u4e2d\u592e\u30c9\u30a5\u30b9\u30f3\u8a9e" },
-            { "or", "\u30aa\u30ea\u30e4\u30fc\u8a9e" },
+            { "or", "\u30aa\u30c7\u30a3\u30a2\u8a9e" },
             { "Modi", "\u30e2\u30fc\u30c7\u30a3\u30fc\u6587\u5b57" },
             { "os", "\u30aa\u30bb\u30c3\u30c8\u8a9e" },
             { "%%ALALC97", "ALA-LC\u30e9\u30c6\u30f3\u6587\u5b57\u5316(1997)" },
