@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -96,6 +96,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "mwl", "\u0645\u06cc\u0631\u0627\u0646\u0688\u06cc\u0632" },
             { "Zsym", "\u0639\u0644\u0627\u0645\u0627\u062a" },
             { "Zsye", "\u0627\u06cc\u0645\u0648\u062c\u06cc" },
+            { "ccp", "\u0686\u06a9\u0645\u06c1" },
             { "tem", "\u0679\u0645\u0646\u06d2" },
             { "teo", "\u062a\u06cc\u0633\u0648" },
             { "rap", "\u0631\u067e\u0627\u0646\u0648\u06cc" },
@@ -330,7 +331,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "MH", "\u0645\u0627\u0631\u0634\u0644 \u0622\u0626\u0644\u06cc\u0646\u0688\u0632" },
             { "ale", "\u0627\u0644\u06cc\u0648\u062a" },
             { "type.nu.vaii", "\u0648\u0627\u0626\u06cc \u06c1\u0646\u062f\u0633\u06d2" },
-            { "MK", "\u0645\u0642\u062f\u0648\u0646\u06cc\u06c1" },
+            { "MK", "\u0634\u0645\u0627\u0644\u06cc \u0645\u0642\u062f\u0648\u0646\u06cc\u06c1" },
             { "ML", "\u0645\u0627\u0644\u06cc" },
             { "MM", "\u0645\u06cc\u0627\u0646\u0645\u0627\u0631 (\u0628\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u06af\u0648\u0644\u06cc\u0627" },
@@ -351,7 +352,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "MY", "\u0645\u0644\u0627\u0626\u0634\u06cc\u0627" },
             { "MZ", "\u0645\u0648\u0632\u0645\u0628\u06cc\u0642" },
             { "NA", "\u0646\u0627\u0645\u06cc\u0628\u06cc\u0627" },
-            { "202", "\u0633\u064e\u0628 \u0635\u062d\u0627\u0631\u0646 \u0627\u0641\u0631\u06cc\u0642\u06c1" },
+            { "202", "\u0630\u06cc\u0644\u06cc \u0635\u062d\u0627\u0631\u0646 \u0627\u0641\u0631\u06cc\u0642\u06c1" },
             { "type.ca.hebrew", "\u0639\u0628\u0631\u0627\u0646\u06cc \u06a9\u06cc\u0644\u0646\u0688\u0631" },
             { "type.co.dictionary", "\u0644\u063a\u062a \u06a9\u06cc \u0686\u06be\u0679\u0646\u06cc \u06a9\u06cc \u062a\u0631\u062a\u06cc\u0628" },
             { "NC", "\u0646\u06cc\u0648 \u06a9\u0644\u06cc\u0688\u0648\u0646\u06cc\u0627" },
@@ -439,7 +440,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "SV", "\u0627\u0644 \u0633\u0644\u0648\u0627\u0688\u0648\u0631" },
             { "SX", "\u0633\u0646\u0679 \u0645\u0627\u0631\u0679\u0646" },
             { "SY", "\u0634\u0627\u0645" },
-            { "SZ", "\u0633\u0648\u0627\u0632\u06cc \u0644\u06cc\u0646\u0688" },
+            { "SZ", "\u0633\u0648\u0627\u062a\u0646\u06cc" },
             { "TA", "\u0679\u0631\u0633\u0679\u0646 \u0688\u0627 \u06a9\u06cc\u0648\u0646\u06c1\u0627" },
             { "asa", "\u0622\u0633\u0648" },
             { "type.ms.ussystem", "\u067e\u06cc\u0645\u0627\u0626\u0634 \u06a9\u0627 \u0627\u0645\u0631\u06cc\u06a9\u06cc \u0646\u0638\u0627\u0645" },
@@ -465,7 +466,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "TW", "\u062a\u0627\u0626\u06cc\u0648\u0627\u0646" },
             { "ast", "\u0627\u0633\u0679\u0648\u0631\u06cc\u0627\u0626\u06cc" },
             { "TZ", "\u062a\u0646\u0632\u0627\u0646\u06cc\u06c1" },
-            { "nmg", "\u0643\u0648\u0627\u064a\u0633\u0648" },
+            { "nmg", "\u06a9\u0648\u0627\u064a\u0633\u0648" },
             { "Zzzz", "\u0646\u0627\u0645\u0639\u0644\u0648\u0645 \u0631\u0633\u0645 \u0627\u0644\u062e\u0637" },
             { "UA", "\u06cc\u0648\u06a9\u0631\u06cc\u0646" },
             { "rup", "\u0627\u0631\u0648\u0645\u0627\u0646\u06cc" },
@@ -511,7 +512,9 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "wae", "\u0648\u0627\u0644\u0633\u0631" },
             { "WS", "\u0633\u0627\u0645\u0648\u0622" },
             { "wal", "\u0648\u0648\u0644\u0627\u06cc\u062a\u0627" },
+            { "XA", "\u0628\u0646\u0627\u0648\u0679\u06cc \u0644\u06c1\u062c\u06d2" },
             { "war", "\u0648\u0627\u0631\u06d2" },
+            { "XB", "\u0645\u0635\u0646\u0648\u0639\u06cc \u0628\u06cc\u0691\u06cc" },
             { "awa", "\u0627\u0648\u0627\u062f\u06be\u06cc" },
             { "061", "\u067e\u0648\u0644\u06cc\u0646\u06cc\u0634\u06cc\u0627" },
             { "XK", "\u06a9\u0648\u0633\u0648\u0648\u0648" },
@@ -597,12 +600,12 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "bo", metaValue_bo },
             { "dgr", "\u062f\u0648\u06af\u0631\u06cc\u0628" },
             { "br", "\u0628\u0631\u06cc\u0679\u0646" },
-            { "bs", "\u0628\u0648\u0633\u0646\u06cc" },
+            { "bs", "\u0628\u0648\u0633\u0646\u06cc\u0627\u0626\u06cc" },
             { "Mymr", "\u0645\u06cc\u0627\u0646\u0645\u0627\u0631" },
             { "type.nu.laoo", "\u0644\u0627\u0624 \u06c1\u0646\u062f\u0633\u06d2" },
             { "seh", "\u0633\u06cc\u0646\u0627" },
             { "ca", "\u06a9\u06cc\u0679\u0627\u0644\u0627\u0646" },
-            { "ses", "\u0643\u0648\u064a\u0631\u0627\u0628\u0648\u0631\u0648 \u0633\u064a\u0646\u06cc" },
+            { "ses", "\u06a9\u0648\u064a\u0631\u0627\u0628\u0648\u0631\u0648 \u0633\u064a\u0646\u06cc" },
             { "ce", "\u0686\u06cc\u0686\u0646" },
             { "ch", "\u0686\u06cc\u0645\u0627\u0631\u0648" },
             { "co", "\u06a9\u0648\u0631\u0627\u0633\u06cc\u06a9\u0646" },
@@ -707,7 +710,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "mas", "\u0645\u0633\u0627\u0626\u06cc" },
             { "kj", "\u06a9\u0648\u0646\u06cc\u0627\u0645\u0627" },
             { "kk", "\u0642\u0632\u0627\u062e" },
-            { "kl", "\u0643\u0627\u0644\u0627\u0644\u064a\u0633\u062a" },
+            { "kl", "\u06a9\u0627\u0644\u0627\u0644\u064a\u0633\u062a" },
             { "km", metaValue_km },
             { "kn", "\u06a9\u0646\u0651\u0627\u0688\u0627" },
             { "ko", metaValue_ko },
@@ -729,7 +732,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "lo", metaValue_lo },
             { "type.ms.uksystem", "\u067e\u06cc\u0645\u0627\u0626\u0634 \u06a9\u0627 \u0627\u0645\u067e\u06cc\u0631\u06cc\u0644 \u0646\u0638\u0627\u0645" },
             { "lt", "\u0644\u06cc\u062a\u06be\u0648\u06cc\u0646\u06cc\u0646" },
-            { "lu", "\u0644\u0628\u0627-\u0643\u0627\u062a\u0627\u0646\u062c\u0627" },
+            { "lu", "\u0644\u0628\u0627-\u06a9\u0627\u062a\u0627\u0646\u062c\u0627" },
             { "lv", "\u0644\u06cc\u0679\u0648\u06cc\u0646" },
             { "ListCompositionPattern", "{0}\u060c{1}" },
             { "mg", "\u0645\u0644\u0627\u06af\u0627\u0633\u06cc" },
@@ -760,7 +763,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "ny", "\u0646\u06cc\u0627\u0646\u062c\u0627" },
             { "kac", "\u06a9\u0627\u0686\u0646" },
             { "kab", "\u0642\u0628\u0627\u0626\u0644\u06cc" },
-            { "oc", "\u0622\u0643\u0633\u06cc\u0679\u0627\u0646" },
+            { "oc", "\u0622\u06a9\u0633\u06cc\u0679\u0627\u0646" },
             { "kaj", "\u062c\u06d2 \u062c\u0648" },
             { "kam", "\u06a9\u0627\u0645\u0628\u0627" },
             { "men", "\u0645\u06cc\u0646\u062f\u06d2" },
@@ -792,7 +795,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.mymr", "\u0645\u06cc\u0627\u0646\u0645\u0627\u0631 \u06a9\u06d2 \u06c1\u0646\u062f\u0633\u06d2" },
             { "qu", "\u06a9\u0648\u06cc\u0686\u0648\u0622" },
             { "brx", "\u0628\u0648\u0688\u0648" },
-            { "kde", "\u0645\u0627\u0643\u0648\u0646\u062f\u0647" },
+            { "kde", "\u0645\u0627\u06a9\u0648\u0646\u062f\u0647" },
             { "Ethi", "\u0627\u06cc\u062a\u06be\u0648\u067e\u06cc\u0627\u0626\u06cc" },
             { "type.hc.h12", "12 \u06af\u06be\u0646\u0679\u06d2 \u06a9\u0627 \u0646\u0638\u0627\u0645 (1\u201312)" },
             { "type.hc.h11", "12 \u06af\u06be\u0646\u0679\u06d2 \u06a9\u0627 \u0646\u0638\u0627\u0645 (0\u201311)" },
@@ -804,7 +807,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.hanidec", "\u0686\u06cc\u0646\u06cc \u0627\u0639\u0634\u0627\u0631\u06cc \u0627\u0639\u062f\u0627\u062f" },
             { "ru", "\u0631\u0648\u0633\u06cc" },
             { "rw", "\u06a9\u06cc\u0646\u06cc\u0627\u0631\u0648\u0627\u0646\u0688\u0627" },
-            { "kea", "\u0643\u0627\u0628\u0648\u064a\u0631\u062f\u064a\u0627\u0646\u0648" },
+            { "kea", "\u06a9\u0627\u0628\u0648\u064a\u0631\u062f\u064a\u0627\u0646\u0648" },
             { "mic", "\u0645\u06a9\u0645\u06cc\u06a9" },
             { "suk", "\u0633\u06a9\u0648\u0645\u0627" },
             { "en_AU", "\u0622\u0633\u0679\u0631\u06cc\u0644\u06cc\u0627\u0626\u06cc \u0627\u0646\u06af\u0631\u06cc\u0632\u06cc" },
@@ -874,10 +877,10 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "ve", "\u0648\u06cc\u0646\u0688\u0627" },
             { "type.ca.roc", "\u0645\u0646\u06af\u0648\u0648 \u06a9\u06cc\u0644\u0646\u0688\u0631" },
             { "vi", "\u0648\u06cc\u062a\u0646\u0627\u0645\u06cc" },
-            { "khq", "\u0643\u0648\u064a\u0631\u0627 \u0634\u064a\u0646\u064a" },
+            { "khq", "\u06a9\u0648\u064a\u0631\u0627 \u0634\u064a\u0646\u064a" },
             { "key.hc", "\u06af\u06be\u0646\u0679\u06c1 \u0633\u0627\u0626\u06cc\u06a9\u0644 (12 \u0628\u0646\u0627\u0645 24)" },
             { "vo", "\u0648\u0648\u0644\u0627\u067e\u0648\u06a9" },
-            { "quc", "\u0643\u064a\u0634\u06cc" },
+            { "quc", "\u06a9\u064a\u0634\u06cc" },
             { "gaa", "\u06af\u0627" },
             { "wa", "\u0648\u0627\u0644\u0648\u0646" },
             { "gag", "\u063a\u0627\u063a\u0627\u0648\u0632" },
@@ -903,7 +906,7 @@ public class LocaleNames_ur extends OpenListResourceBundle {
             { "type.nu.traditional", "\u0631\u0648\u0627\u06cc\u062a\u06cc \u0627\u0639\u062f\u0627\u062f" },
             { "es_MX", "\u0645\u06cc\u06a9\u0633\u06cc\u06a9\u0646 \u06c1\u0633\u067e\u0627\u0646\u0648\u06cc" },
             { "vai", "\u0648\u0627\u0626\u06cc" },
-            { "kln", "\u0643\u0627\u0644\u064a\u0646\u062c\u064a\u0646" },
+            { "kln", "\u06a9\u0627\u0644\u064a\u0646\u062c\u064a\u0646" },
             { "zh", "\u0686\u06cc\u0646\u06cc" },
             { "Bopo", "\u0628\u0648\u067e\u0648\u0645\u0648\u0641\u0648" },
             { "key.lb", "\u0644\u0627\u0626\u0646 \u0628\u0631\u06cc\u06a9 \u0627\u0646\u062f\u0627\u0632" },
