@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de las islas Malvinas",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "hora de But\u00e1n",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "hora est\u00e1ndar de Apia",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de Apia",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "hora de But\u00e1n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "hora de Nauru",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "hora est\u00e1ndar de Colombia",
+        final String[] Australia_Eastern = new String[] {
+               "hora est\u00e1ndar de Australia oriental",
                "",
-               "hora de verano de Colombia",
+               "hora de verano de Australia oriental",
                "",
-               "hora de Colombia",
+               "hora de Australia oriental",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "hora est\u00e1ndar de Australia oriental",
+        final String[] Colombia = new String[] {
+               "hora est\u00e1ndar de Colombia",
                "",
-               "hora de verano de Australia oriental",
+               "hora de verano de Colombia",
                "",
-               "hora de Australia oriental",
+               "hora de Colombia",
                "",
             };
         final String[] Chile = new String[] {
@@ -1054,12 +1054,12 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "hora est\u00e1ndar del noroeste de M\u00e9xico",
+        final String[] Volgograd = new String[] {
+               "hora est\u00e1ndar de Volgogrado",
                "",
-               "hora de verano del noroeste de M\u00e9xico",
+               "hora de verano de Volgogrado",
                "",
-               "hora del noroeste de M\u00e9xico",
+               "hora de Volgogrado",
                "",
             };
         final String[] Easter = new String[] {
@@ -1070,6 +1070,14 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de la isla de Pascua",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "hora est\u00e1ndar del noroeste de M\u00e9xico",
+               "",
+               "hora de verano del noroeste de M\u00e9xico",
+               "",
+               "hora del noroeste de M\u00e9xico",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "hora de Dumont-d\u2019Urville",
                "",
@@ -1222,14 +1230,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de Samara",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "hora de Pyongyang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "hora est\u00e1ndar de la India",
                "",
@@ -1260,7 +1260,16 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1344,7 +1353,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1454,12 +1462,12 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nueva York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Acra" },
             { "timezone.excity.Etc/Unknown", "ciudad desconocida" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Gran Turca" },
             { "America/Yakutat", Alaska },
@@ -1520,8 +1528,17 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Santa Elena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburgo" },
             { "America/Cayman", America_Eastern },
@@ -1678,7 +1695,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
             { "timezone.excity.America/Los_Angeles", "Los \u00c1ngeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1715,6 +1731,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostan\u00e1i" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1886,7 +1903,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1911,7 +1928,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atenas" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1933,6 +1950,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jerusal\u00e9n" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2095,7 +2113,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Estambul" },
             { "America/Rio_Branco", Acre },
@@ -2107,7 +2125,6 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "Africa/Lusaka", Africa_Central },
             { "timezone.excity.Africa/Tunis", "T\u00fanez" },
-            { "timezone.excity.Asia/Macau", "Macao" },
             { "America/Argentina/La_Rioja", Argentina },
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
